@@ -33,27 +33,7 @@ def defaulterrorhandler(connection, cursor, errorclass, errorvalue):
     raise errorclass, errorvalue
 
 
-if hasattr(types, "ObjectType"):
-
-    class ConnectionBase(_mysql.connection):
-
-        def _make_connection(self, args, kwargs):
-            apply(super(ConnectionBase, self).__init__, args, kwargs)
-
-else:
-    
-    class ConnectionBase:
-        
-        def _make_connection(self, args, kwargs):
-            self._db = apply(_mysql.connect, args, kwargs)
-            
-        def __getattr__(self, attr):
-            if hasattr(self, "_db"):
-                return getattr(self._db, attr)
-            raise AttributeError, attr
-
-        
-class Connection(ConnectionBase):
+class Connection(_mysql.connection):
 
     """
 
@@ -80,6 +60,7 @@ class Connection(ConnectionBase):
             unicode objects with this encoding. If set to None, the
             default encoding is used. If not set at all, character
             columns are returned as normal strings.
+    client_flag -- integer, flags to use or 0 (see MySQL docs or constants/CLIENTS.py)
 
     There are a number of undocumented, non-standard methods. See the
     documentation for the MySQL C API for some hints on what they do.
@@ -109,14 +90,16 @@ class Connection(ConnectionBase):
                 u = lambda s, c=charset: unicode(s, c)
             else:
                 u = unicode
-            conv[FIELD_TYPE.CHAR] = u
             conv[FIELD_TYPE.STRING] = u
             conv[FIELD_TYPE.VAR_STRING] = u
-        self._make_connection(args, kwargs2)
+            conv[FIELD_TYPE.BLOB].insert(-1, (None, u))
+        super(Connection, self).__init__(*args, **kwargs2)
         self.converter[types.StringType] = self.string_literal
-        if hasattr(types, 'UnicodeType'):
-            self.converter[types.UnicodeType] = self.unicode_literal
+        self.converter[types.UnicodeType] = self.unicode_literal
         self._transactional = self.server_capabilities & CLIENT.TRANSACTIONS
+        if self._transactional:
+            # PEP-249 requires autocommit to be initially off
+            self.autocommit(0)
         self.messages = []
         
     def __del__(self):
@@ -124,23 +107,32 @@ class Connection(ConnectionBase):
             self.close()
         except:
             pass
-        
-    def begin(self):
-        """Explicitly begin a transaction. Non-standard."""
-        self.query("BEGIN")
-        
-    def commit(self):
-        """Commit the current transaction."""
-        if self._transactional:
-            self.query("COMMIT")
-            
-    def rollback(self):
-        """Rollback the current transaction."""
-        if self._transactional:
-            self.query("ROLLBACK")
+
+    def autocommit(self, flag):
+        """Set the autocommit stage. A True value enables autocommit;
+        a False value disables it. PEP-249 requires autocommit to be
+        initially off."""
+        flag = flag == True
+        s = super(Connection, self)
+        if hasattr(s, 'autocommit'):
+            s.autocommit(flag)
         else:
-            self.errorhandler(None,
-                              NotSupportedError, "Not supported by server")
+            self.query("SET AUTOCOMMIT=%d" % flag)
+            
+    if not hasattr(_mysql.connection, 'commit'):
+        
+        def commit(self):
+            """Commit the current transaction."""
+            if self._transactional:
+                self.query("COMMIT")
+
+        def rollback(self):
+            """Rollback the current transaction."""
+            if self._transactional:
+                self.query("ROLLBACK")
+            else:
+                self.errorhandler(None,
+                                  NotSupportedError, "Not supported by server")
             
     def cursor(self, cursorclass=None):
         """
